menu
fancy_bottom_navigation_plus package
documentation
components/half_clipper.dart
components/half_clipper.dart
dark_mode
light_mode
components/half_clipper
library
Classes
HalfClipper
HalfClipper
is a custom
Rect
clipper that clips the bottom half of a widget. It is used to create the background shadow effect for the floating circle.
fancy_bottom_navigation_plus package
documentation
components/half_clipper.dart
fancy_bottom_navigation_plus
package
Libraries
components/half_clipper
components/half_painter
components/tab_item
fancy_bottom_navigation_plus
half_clipper library