components/tab_item library

Classes

TabItem
TabItem is an internal widget used to render an individual tab within the FancyBottomNavigationPlus bar.

Constants

iconOff → const double
Position of the icon when it is not selected.
iconOn → const double
Position of the icon when it is selected.
textOff → const double
Position of the text when it is not selected.
textOn → const double
Position of the text when it is selected.