TabItem class

TabItem is an internal widget used to render an individual tab within the FancyBottomNavigationPlus bar.

Inheritance

Constructors

TabItem({Key? key, int animDuration = 300, required bool selected, required String title, required UniqueKey uniqueKey, required Widget icon, TextStyle? titleStyle, required dynamic callbackFunction(UniqueKey uniqueKey), Color? activeIconColor, Color? inactiveIconColor})
Creates a TabItem.
const

Properties

activeIconColor → Color?
Optional color for the icon when the tab is active.
final
animDuration → int
The duration of the transition animations.
final
callbackFunction → dynamic Function(UniqueKey uniqueKey)
Callback function triggered when this tab is tapped.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
The icon widget to display.
final
inactiveIconColor → Color?
Optional color for the icon when the tab is inactive.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
Whether this tab is currently selected.
final
title → String
The text label to display.
final
titleStyle → TextStyle?
Custom text style for the label.
final
uniqueKey → UniqueKey
The unique key associated with this tab.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited