iconOff top-level constant
double
const iconOff
Position of the icon when it is not selected.
Implementation
const double iconOff = -3;
Position of the icon when it is not selected.
const double iconOff = -3;