textOff top-level constant
double
const textOff
Position of the text when it is not selected.
Implementation
const double textOff = 3;
Position of the text when it is not selected.
const double textOff = 3;