fancy_bottom_navigation_plus library

Classes

FancyBottomNavigationPlus
FancyBottomNavigationPlus is a highly customizable, animated bottom navigation bar developed in Flutter. It features a floating circle animation that moves smoothly when tabs are switched, providing a premium feel to your application.
FancyBottomNavigationPlusState
TabData
TabData is a model used to define a single tab in FancyBottomNavigationPlus.